@@ -6,7 +6,7 @@
 # define PY_SSIZE_T_CLEAN
 # include "Python.h"
 
-# define PY_ARRAY_UNIQUE_SYMBOL AK_ARRAY_API
+# define PY_ARRAY_UNIQUE_SYMBOL AM_ARRAY_API
 # define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 
 # include "numpy/arrayobject.h"
